@@ -995,6 +995,9 @@ class QueryBuilder(Selectable, Term):
     def cross_join(self, item: Union[Table, "QueryBuilder", AliasedQuery]) -> "Joiner":
         return self.join(item, JoinType.cross)
 
+    def hash_join(self, item: Union[Table, "QueryBuilder", AliasedQuery]) -> "Joiner":
+        return self.join(item, JoinType.hash)
+
     @builder
     def limit(self, limit: int) -> "QueryBuilder":
         self._limit = limit
